@@ -21,9 +21,9 @@
 #include <gdk/gdkkeysyms.h>
 #include <string.h>
 
-#include <hildon-widgets/hildon-set-password-dialog.h>
-#include <hildon-widgets/hildon-get-password-dialog.h>
-#include <hildon-widgets/hildon-banner.h>
+#include <hildon/hildon-set-password-dialog.h>
+#include <hildon/hildon-get-password-dialog.h>
+#include <hildon/hildon-banner.h>
 
 #include "config.h"
 #include "main.h"
